import pkg_resources  # type: ignore[import]

__version__ = pkg_resources.get_distribution("signal-export").version
